@@ -91,6 +91,60 @@ class AllValuesFilterTest(TestCase):
         self.assertEqual(list(F({'username': 'alex'})), [User.objects.get(username='alex')])
         self.assertEqual(list(F({'username': 'jose'})), list(User.objects.all()))
 
+class InitialValueTest(TestCase):
+    fixtures = ['test_data']
+
+    def test_initial(self):
+        class F(django_filters.FilterSet):
+            status = django_filters.ChoiceFilter(choices=STATUS_CHOICES, initial=1)
+            class Meta:
+                model = User
+                fields = ['status']
+        self.assertEqual(list(F().qs), [User.objects.get(username='alex')])
+        self.assertEqual(list(F({'status': 0})), list(User.objects.filter(status=0)))
+
+
+class RelatedObjectTest(TestCase):
+    fixtures = ['test_data']
+    
+    def test_foreignkey(self):
+        class F(django_filters.FilterSet):
+            class Meta:
+                model = Article
+                fields = ['author__username']
+        self.assertEqual(F.base_filters.keys(), ['author__username'])
+        form_html = ('<tr><th><label for="id_author__username">Username:</label>'
+            '</th><td><input type="text" name="author__username" '
+            'id="id_author__username" /></td></tr>')
+        self.assertEqual(str(F().form), form_html)
+        self.assertEqual(F({'author__username': 'alex'}).qs.count(), 2)
+        self.assertEqual(F({'author__username': 'jacob'}).qs.count(), 1)
+
+        class F(django_filters.FilterSet):
+            author__username = django_filters.AllValuesFilter()
+            class Meta:
+                model = Article
+                fields = ['author__username']
+            
+        form_html = ('<tr><th><label for="id_author__username">Author  '
+            'username:</label></th><td><select name="author__username" '
+            'id="id_author__username">\n<option value="alex">alex</option>\n'
+            '<option value="jacob">jacob</option>\n</select></td></tr>')
+        self.assertEqual(str(F().form), form_html)
+
+
+class MultipleChoiceFilterTest(TestCase):
+    fixtures = ['test_data']
+
+    def test_all_choices_selected(self):
+        class F(django_filters.FilterSet):
+            class Meta:
+                model = User
+                fields = ["status"]
+        
+        self.assertEqual(list(F({"status": [0, 1]}).qs), list(User.objects.all()))
+
+
 filter_tests = """
 >>> from datetime import datetime
 >>> from django import forms
